@@ -12,9 +12,8 @@ from .low_density_identification import (
     low_density_identification_threshold,
     low_density_identification_z_scores,
 )
-from .outliers import extreme, out_of_range
+from .outliers import extreme
 from .rolling_stddev import rolling_stddev_timedelta
-from .uncertainty import uncertainty_rstd
 from .value_decrease_indication import value_decrease_check
 
 
@@ -30,8 +29,6 @@ __all__ = [
     "low_density_identification_threshold",
     "low_density_identification_z_scores",
     "extreme",
-    "out_of_range",
     "value_decrease_check",
-    "uncertainty_rstd",
     "rolling_stddev_timedelta",
 ]
