@@ -7,8 +7,7 @@ import pandas as pd
 from numpy.polynomial import polynomial
 from scipy.stats import t as student_dist
 
-from indsl.filter import trend_extraction_hilbert_transform as get_trend
-from indsl.resample import reindex
+from indsl.resample.reindex import reindex
 from indsl.smooth import sg
 
 from ..exceptions import UserValueError
@@ -83,12 +82,9 @@ def extreme(data: pd.Series, alpha: float = 0.05, bc_relaxation: float = 0.167,
 @check_types
 def out_of_range(
     data: pd.Series,
-    use_sg_pass01: bool = True,
-    use_sg_pass02: bool = False,
     window_length: List[int] = [20, 20],
     polyorder: List[int] = [3, 3],
     alpha: List[float] = [0.05, 0.05],
-    tolerance: List[float] = [0.08, 0.01],
     bc_relaxation: List[float] = [0.25, 0.5],
     return_outliers: bool = True,
 ) -> pd.Series:
@@ -99,24 +95,21 @@ def out_of_range(
     only exception, the method is designed for *non-linear, non-stationary sensor data*, one of the most common type
     of time series in physical processes.
 
-    Outliers are detected using an iterative, data-adaptive method based on digital filtering, signal decomposition and
-    statistical inference. Additional details on the analytical methods are provided below. But it is basically a
-    three step process, carried out in two iterations. The three steps are::
+    Outliers are detected using an iterative and data-adaptive method. Additional details on the analytical methods are provided below. But it is basically a
+    three step process, carried out in two iterations. The three steps are:
 
-    1. Estimate the main trend of the time series using one of two methods:
+    1. Estimate the main trend of the time series using the method:
 
         * Savitzky-Golay smoothing (`SG <https://en.wikipedia.org/wiki/Savitzky%E2%80%93Golay_filter>`_).
-        * Empirical mode decomposition - Hilbert Huang Transform (`EMD-HHT <https://emd.readthedocs.io/en/stable/>`_).
 
     2. Estimate the `studentized residuals <https://en.wikipedia.org/wiki/Studentized_residual>`_.
 
     3. Identify outliers using the `bonferroni correction <https://mathworld.wolfram.com/BonferroniCorrection.html>`_
        or bonferroni outlier test.
 
-    The results from the first iteration (new time series without the detected outliers) are uses to carry out the
-    second iteration. Each of the methods used to estimate the main trend has pros and cons, but their combination is
-    an effective way to leverage each of their strengths. The `Student's t-distribution
-    <https://en.wikipedia.org/wiki/Student%27s_t-distribution>`_ is used as it useful when
+    The results from the first iteration (new time series without the detected outliers) are used to carry out the
+    second iteration.
+    The `Student's t-distribution <https://en.wikipedia.org/wiki/Student%27s_t-distribution>`_ is used as it useful when
     estimating the mean of a normally distributed population in situations where the sample size is small and
     the population's standard deviation is unknown. Finally, the bonferroni correction or Boneferroni test is
     a simple and efficient method to tests for extreme outliers. Additional details on each of these methods is
@@ -131,16 +124,6 @@ def out_of_range(
     of data points used to estimate the local trend and the `polynomial order` is used to fit those data points with a
     linear (order 1) or non-linear (order higher than 1) fit.
 
-    **Empirical Mode Decomposition - Hilbert Huang Transform**:
-
-    This is a data-adaptive method that decomposes a signal into oscillatory components and rejects those with low
-    energy (e.g.. high frequency random noise) base on given energy `tolerance` or threshold. A small tolerance
-    will allow more oscillatory components as  part of the main (more high-frequency components), while a large
-    `tolerance` will result on a smoother trend. The algorithm implemented here is an adaptation from the
-    `EMD-HHT <https://emd.readthedocs.io/en/stable/>`_ library. For more information on the EMD-HHT method
-    consult the original paper in the Journal of Open Source Software
-    `JOSS <https://joss.theoj.org/papers/10.21105/joss.02977>`_.
-
     **Studentized residuals and the Bonferroni Correction**:
 
     The `Student's t-distribution <https://en.wikipedia.org/wiki/Student%27s_t-distribution>`_ is typically used when
@@ -155,16 +138,6 @@ def out_of_range(
 
     Args:
         data: Time series.
-        use_sg_pass01: Pass 1: Simple smoother.
-            Use the Savitzky-Golay (SG) smoother in the first iteration to determine the main trend of the signal.
-            If set to `True`, the parameters `window length` and `polynomial order` are required. If set to `False`,
-            the parameter `tolerance` is required to obtain the trend using the EMD-HHT
-            method. The default is `True`.
-        use_sg_pass02: Pass 2: Simple smoother.
-            Use the Savitzky-Golay (SG) smoother in the second iteration to determine the main trend of the signal.
-            If set to `True`, the parameters `window length` and `polynomial order` are required. If set to `False`,
-            the parameter `tolerance` is required to obtain the trend using the EMD-HHT
-            method. The default is `False`.
         window_length: Window length.
             Point-wise window length used to estimate the local trend using the SG smoother. Two integer values are
             required, one for each iteration. If the SG smoother is not used, these values are ignored. Default value
@@ -177,10 +150,6 @@ def out_of_range(
             is the probability of detecting an outlier that is not a true outlier. A value of 0.05 means that
             there is a 5% risk of detecting an outlier that is not a true outlier. Defaults to 0.05 for both
             iterations.
-        tolerance: Tolerance.
-            Energy tolerance (or threshold) used to validate if an oscillatory component identified by the EMD-HHT
-            methodology should be included as part of the main trend.
-            Defaults to 0.08 and 0.01.
         bc_relaxation: Sensitivity.
             Number higher than 0 used to make outlier detection more or less sensitive. Smaller values will make
             the detection more conservative. Defaults 0.25 and 0.5 for the first and second iterations, respectively.
@@ -195,7 +164,7 @@ def out_of_range(
     data = data.dropna()
 
     validate_series_has_minimum_length(data, 3)
-    _validations(alpha, bc_relaxation, tolerance, window_length, polyorder)
+    _validations(alpha, bc_relaxation, window_length, polyorder)
 
     x, y = _split_timeseries_into_time_and_value_arrays(data)
 
@@ -203,11 +172,8 @@ def out_of_range(
     # FIRST PASS
     # ==========
 
-    # Estimate the trend using Savitzky-Golay smoother or Empirical Mode Decomposition (EMD) and the Hilbert Huang Transform (HHT)
-    if use_sg_pass01:
-        trend_pass01 = sg(data, window_length=window_length[0], polyorder=polyorder[0])
-    else:
-        trend_pass01 = get_trend(data, error_tolerance=tolerance[0])
+    # Estimate the trend using Savitzky-Golay smoother
+    trend_pass01 = sg(data, window_length=window_length[0], polyorder=polyorder[0])
 
     # Detect outliers based on first trend estimate
     x, y = _split_timeseries_into_time_and_value_arrays(data)
@@ -231,10 +197,7 @@ def out_of_range(
     # ===========
 
     # Filtering parameters
-    if use_sg_pass02:
-        trend_pass02 = sg(filtered_ts_pass01, window_length=window_length[1], polyorder=polyorder[1])
-    else:
-        trend_pass02 = get_trend(filtered_ts_pass01, error_tolerance=tolerance[1])
+    trend_pass02 = sg(filtered_ts_pass01, window_length=window_length[1], polyorder=polyorder[1])
 
     y_pred_pass02 = reindex(trend_pass02, data)
     y_pred_pass02 = y_pred_pass02.to_numpy()
@@ -258,9 +221,7 @@ def out_of_range(
     return res
 
 
-def _validations(alpha, bc_relaxation, tolerance, window_length, polyorder):
-    if not all(i > 0.0 for i in tolerance):
-        raise UserValueError("The Error Tolerance must be a number higher than zero.")
+def _validations(alpha, bc_relaxation, window_length, polyorder):
     if not all(0 <= i < 1 for i in alpha):
         raise UserValueError(
             "The Significance Level (alpha) must be a number higher than or equal to 0 and lower " "than 1"
@@ -273,8 +234,6 @@ def _validations(alpha, bc_relaxation, tolerance, window_length, polyorder):
         raise UserValueError(f"The polynomial order parameter requires two values, got {polyorder}")
     if len(alpha) != 2:
         raise UserValueError(f"The Significance Level (alpha) parameter requires two values, got {alpha}")
-    if len(tolerance) != 2:
-        raise UserValueError(f"The tolerance order parameter requires two values, got {tolerance}")
     if len(bc_relaxation) != 2:
         raise UserValueError(f"The sensitivity parameter requires two values, got {bc_relaxation}")
 
