@@ -18,8 +18,8 @@ def rolling_stddev_timedelta(
         data: Time series.
         time_window: Time window.
             Length of the time period to compute the standard deviation for. Defaults to 'minutes=15'.
-            Time unit should be in days, hours, minutes, or seconds. Accepted formats can be found `here
-            (https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.html)`_.
+            Time unit should be in days, hours, minutes, or seconds. Accepted formats can be found here
+            https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.html.
         min_periods: Minimum samples.
             Minimum number of observations required in the given time window (otherwise, the result is set to 0).
             Defaults to 1.
