@@ -8,7 +8,7 @@ from ..validations import validate_series_has_time_index
 
 
 @check_types
-def resample_timeseries(data: pd.Series) -> pd.Series:
+def resample_timeseries(data: pd.Series, is_step: bool = False) -> pd.Series:
     """Resample timeseries.
 
     Resamples a timeseries (provided as a pandas Series with datetime index)
@@ -17,6 +17,8 @@ def resample_timeseries(data: pd.Series) -> pd.Series:
 
     Args:
         data: Time series
+        is_step: Defines if the input time series is a step timeseries
+                 Defaults to False
 
     Returns:
         pandas.Series: Resampled Time series
@@ -37,11 +39,14 @@ def resample_timeseries(data: pd.Series) -> pd.Series:
 
     # create a new series with equally spaced timestamps and join it with input data
     index: pd.DatetimeIndex = pd.date_range(start=min_time, end=max_time, freq=frequency)
-    data_equally_spaced: pd.Series = pd.DataFrame(index=index)
+    data_equally_spaced: pd.DataFrame = pd.DataFrame(index=index)
     data_missing_values: pd.Series = data_equally_spaced.join(data.rename("new"), how="outer").iloc[:, 0]
 
-    # use linear interpolation to estimate missing values
-    data_interpolated: pd.Series = data_missing_values.interpolate(method="linear")
+    # interpolate missing values
+    if is_step:
+        data_interpolated = data_missing_values.interpolate(method="ffill")
+    else:
+        data_interpolated = data_missing_values.interpolate(method="time")
 
     # only keep data for the equally spaced timestamps
     data_clean: pd.Series = data_equally_spaced.join(data_interpolated.rename("new"), how="left").iloc[:, 0]
