@@ -6,7 +6,7 @@ from indsl.type_check import check_types
 
 
 @check_types
-def Haaland(Re: pd.Series, roughness: float):
+def Haaland(Re: pd.Series, roughness: float) -> pd.Series:
     """Haaland equation.
 
     The `Haaland equation <https://en.wikipedia.org/wiki/Darcy_friction_factor_formulae#Haaland_equation>`_ was
