@@ -2,6 +2,7 @@ import functools
 
 from typing import List
 
+from indsl import versioning
 from indsl.data_quality import extreme
 from indsl.detect import drift, ssid, vma
 from indsl.filter import status_flag_filter, wavelet_filter
@@ -53,7 +54,6 @@ from indsl.ts_utils import (
     tanh,
     trapezoidal_integration,
 )
-from indsl.versioning import register
 
 
 old_to_new = {
@@ -122,6 +122,13 @@ old_to_new = {
 }
 
 for old_op_code, f in old_to_new.items():
+
+    # If multiple versions exist, use version 1.0
+    try:
+        f = versioning.get(versioning.get_name(f), "1.0")
+    except ValueError:
+        pass
+
     # inDSLs versioning does not support giving a function two names
     # (here e.g. SIN and sin). We work around this by creating a
     # dummy-wrapper function
@@ -131,7 +138,9 @@ for old_op_code, f in old_to_new.items():
     f_cpy = make_cpy(f)
 
     # Register function as a deprecated function with the old op code
-    register("1.0", old_op_code, deprecated=True, changelog="Deprecated function. Re-create node to upgrade")(f_cpy)
+    versioning.register(
+        "1.0", old_op_code, deprecated=True, changelog="Deprecated function. Re-create node to upgrade"
+    )(f_cpy)
 
     # Attach function to this module
     vars()[old_op_code] = f_cpy
