@@ -1,15 +1,11 @@
 # Copyright 2022 Cognite AS
+from .group_by import group_by_region
 from .interpolate import interpolate
 from .reindex import reindex
 from .resample import resample, resample_to_granularity
 
 
-__all__ = [
-    "interpolate",
-    "resample",
-    "resample_to_granularity",
-    "reindex",
-]
+__all__ = ["interpolate", "resample", "resample_to_granularity", "group_by_region", "reindex"]
 
 
 TOOLBOX_NAME = "Resample"
