@@ -3,7 +3,10 @@ from typing import Optional
 import numpy as np
 import pandas as pd
 
+from ..type_check import check_types
 
+
+@check_types
 def white_noise(
     data: pd.Series,
     snr_db: float = 30,
@@ -15,14 +18,14 @@ def white_noise(
 
     Args:
         data: Time series
-        snr_db: SNR
+        snr_db: SNR.
             Signal-to-noise ratio (SNR) in decibels. SNR is a comparison of the level of a signal to the level of
-            background noise. SNR is defined as the ratio of signal power to the noise power. A ratio higher than 1
+            background noise. SNR is defined as the ratio of signal power to noise power. A ratio higher than 1
             indicates more signal than noise. Defaults to 30.
-        seed: Seed
+        seed: Seed.
             A seed (integer number) to initialize the random number generator. If left empty, then a fresh,
-            unpredictable values will be generated. If a value is entered the exact random noise will be generated if
-            the time series data and date range is not changed.
+            unpredictable value will be generated. If a value is entered, the exact random noise will be generated if
+            the time series data and date range are not changed.
 
     Returns:
         pandas.Series: Output
