@@ -18,8 +18,8 @@ def univariate_polynomial(signal: pd.Series, coefficients: List[float] = [0.0, 1
 
     Args:
         signal: Time series
-        coefficients: Coefficients
-            List of coefficient separated by commas. The numbers must be entered deparated by semicolons (e.g. 0; 1).
+        coefficients: Coefficients.
+            List of coefficients separated by semicolons. The numbers must be entered, separated by semicolons (e.g., 0; 1).
             The default is :math:`0.0; 1.0`, which returns the original time series.
 
     Returns:
