@@ -1,5 +1,5 @@
-# Copyright 2021 Cognite AS
-from typing import List
+# Copyright 2022 Cognite AS
+from typing import List, Union
 
 import numpy as np
 import pandas as pd
@@ -10,13 +10,13 @@ from ..validations import validate_series_has_time_index, validate_series_is_not
 
 
 @check_types
-def alma(data: pd.Series, window: int = 10, sigma: float = 6, offset_factor: float = 0.75):
+def alma(data: pd.Series, window: int = 10, sigma: float = 6, offset_factor: float = 0.75) -> pd.Series:
     """Arnaud Legoux moving average.
 
-    Moving average typically used in the financial industry which aims to strike a good balance between smoothness
-    and responsivness (i.e. capture a general smoothed trend without allowing for significant lag). It can be
-    interpreted as a Gaussian weighted moving average with an offset, where the offset, spread and window size are
-    user defined.
+    Moving average typically used in the financial industry, which aims to strike a good balance between smoothness
+    and responsiveness (i.e., capture a general smoothed trend without allowing for significant lag). It can be
+    interpreted as a Gaussian weighted moving average with an offset, where the offset, spread, and window size are
+    user-defined.
 
     Args:
         data: Time series.
@@ -31,7 +31,7 @@ def alma(data: pd.Series, window: int = 10, sigma: float = 6, offset_factor: flo
     Raises:
         UserValueError: Time series is empty.
         UserValueError: Data has to be a time series.
-        UserValueError: Not enough data to perform calculation.
+        UserValueError: Not enough data to perform the calculation.
 
     Returns:
         pandas.Series: Smoothed data.
@@ -62,7 +62,8 @@ def alma(data: pd.Series, window: int = 10, sigma: float = 6, offset_factor: flo
     return res.dropna()
 
 
-def calculate_alma(values: List, weights: np.ndarray):
+@check_types
+def calculate_alma(values: Union[List, pd.Series], weights: np.ndarray) -> float:
     """Calculate alma value for a window time.
 
     Args:
