@@ -23,8 +23,8 @@ def pearson_correlation(
         data2: Time series.
         time_window: Time window.
             Length of the time period to compute the Pearson correlation. Defaults to 'minutes=15'.
-            Time unit should be in days, hours, minutes or seconds. Accepted formats can be found `here
-            (https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.html)`_.
+            Time unit should be in days, hours, minutes or seconds. Accepted formats can be found here:
+            https://pandas.pydata.org/docs/reference/api/pandas.Timedelta.html.
         min_periods: Minimum samples.
             Minimum number of observations required in the given time window (otherwise, the result is set to 0).
             Defaults to 1.
