@@ -1,5 +1,6 @@
 # Copyright 2022 Cognite AS
 from .logarithmic_functions import exp, log, log2, log10, logn
+from .logical_operations import logical_check
 from .numerical_calculus import differentiate, sliding_window_integration, trapezoidal_integration
 from .operators import absolute, add, arithmetic_mean, div, inv, mod, mul, neg, power, sqrt, sub
 from .trigonometric_functions import (
@@ -90,4 +91,5 @@ __all__ = [
     "threshold",
     "sliding_window_integration",
     "arithmetic_mean",
+    "logical_check",
 ]
