@@ -27,3 +27,12 @@ def validate_timedelta_unit(timedelta: pd.Timedelta) -> None:
     """Helper method to validate if the provided pd.Timedelta is larger or equal to 1 second."""
     if timedelta < pd.Timedelta(seconds=1):
         raise UserValueError("Unit of timedelta should be in days, hours, minutes or seconds")
+
+
+def validate_timedelta(timedelta: pd.Timedelta) -> None:
+    """Helper method to validate if the provided pd.Timedelta valid: not NaT and strictly larger than zero."""
+    if timedelta is pd.NaT:
+        raise UserValueError("Timedelta is invalid (NaT).")
+
+    if timedelta.value < 0:
+        raise UserValueError("Timedelta must be strictly positive. The smallest possible value is '1ns'")
