@@ -16,7 +16,7 @@ def register(
     name: Optional[str] = None,
     deprecated: Optional[bool] = False,
     changelog: Optional[str] = None,
-):
+) -> Callable[..., Any]:
     """Decorator to register a new versioned function.
 
     Args:
@@ -44,9 +44,9 @@ def register(
                 a
         name: Name of the function
             The name under which the function should be registered. If no name
-            is specified, the name of the funtion is used.
-        deprecated: Flag is function is deprecated. Default: False
-        changelog: Description on what has changed since the previous version. Default: None
+            is specified, the name of the function is used.
+        deprecated: Flag if function is deprecated. Default: False
+        changelog: Description of what has changed since the previous version. Default: None
     """
     # Test that the version numbering is valid
     Version(version)
